# Generated by roxygen2: do not edit by hand

S3method(as_tibble,bid_issues)
S3method(as_tibble,bid_stage)
S3method(bid_flags,bid_issues)
S3method(bid_flags,default)
S3method(print,bid_bias_mitigations)
S3method(print,bid_data_story)
S3method(print,bid_issues)
S3method(print,bid_result)
S3method(print,bid_stage)
S3method(print,bid_user_personas)
S3method(summary,bid_result)
S3method(summary,bid_stage)
export(bid_address)
export(bid_anticipate)
export(bid_concept)
export(bid_concepts)
export(bid_flags)
export(bid_get_quiet)
export(bid_ingest_telemetry)
export(bid_interpret)
export(bid_notice)
export(bid_notice_issue)
export(bid_notices)
export(bid_pipeline)
export(bid_quick_suggest)
export(bid_report)
export(bid_result)
export(bid_set_quiet)
export(bid_stage)
export(bid_structure)
export(bid_suggest_analytics)
export(bid_suggest_components)
export(bid_telemetry)
export(bid_telemetry_presets)
export(bid_validate)
export(bid_with_quiet)
export(convert_otel_spans_to_events)
export(extract_stage)
export(get_accessibility_recommendations)
export(get_concept_bias_mappings)
export(get_layout_concepts)
export(get_metadata)
export(get_stage)
export(is_bid_stage)
export(is_complete)
export(new_bias_mitigations)
export(new_data_story)
export(new_user_personas)
export(suggest_theory_from_mappings)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbListTables)
importFrom(DBI,dbReadTable)
importFrom(DBI,dbWriteTable)
importFrom(RSQLite,SQLite)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_info)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,select)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(memoise,memoise)
importFrom(readr,read_csv)
importFrom(rlang,"%||%")
importFrom(rlang,enexpr)
importFrom(rlang,eval_tidy)
importFrom(rlang,quo_is_null)
importFrom(stats,complete.cases)
importFrom(stats,median)
importFrom(stats,setNames)
importFrom(stringdist,stringdistmatrix)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,timestamp)
